'*********************************************
' * VBScript-NMRScript Header, v1-80721
' *
' * use 'App.CommandName' to communicate 
' * with the Application Object
' * use 'Data.CommandName' to communicate 
' * with the topmost data file (Document Object)
' 
    Dim App, Data, pathToDoc
    'CreateObject ("NTNMR.Application") 
    Set App = GetObject(, "NTNMR.Application")
    pathToDoc = App.GetActiveDocPath
    Set Data = GetObject(pathToDoc)
' ********************************************

' 2D RuSH processing script
' C.D.Gregory, Tecmag, Inc.
version = "2D RuSH Process v.020708"
result = MsgBox("Set System Phase by phasing 1D spectrum first!", vbOKCancel, version)
if result = 1 then

' Get dashboard dimension info for zero-fills, apodizations 
Pts1D = Data.GetNMRParameter("Acq. Points")
Pts2D = Data.GetNMRParameter("Actual Points 2D")
Temp = "Raw Data is " & Pts1D & " x " & Pts2D
Pts1DFinal = inputbox(Temp & vbcrlf & "Points to compute in direct dimension", version, Pts1D)
Pts2DFinal = inputbox(Temp & vbcrlf & "Points to compute in indirect dimension", version, Pts2D)

' Fix direct dimension data set size
' If data is larger than required, reduce it
while ((Pts1DFinal - Data.GetNMRParameter("Points 1D")) < 0 )
 Data.ReadFirstHalf
wend
' if data is smaller than required, compute a zerofill parameter
temp = Pts1D
zf1d = 0
while ((temp-Pts1DFinal) < 0)
 zf1d = zf1d + 1
 temp = 2 * temp
wend

' Fix indirect dimension data set size the same way
Data.Transpose
while ((Pts2DFinal - Data.GetNMRParameter("Points 1D")) < 0 )
 Data.ReadFirstHalf
wend
Data.Transpose
temp = Pts2D
zf2d = 0
while ((temp-Pts2DFinal) < 0)
 zf2d = zf2d + 1
 temp = 2 * temp
wend

' Double the 2D dimension (again) since we lose half the data with the RuSH method
Pts2DFinal = 2 * Pts2DFinal
zf2d = zf2d + 1

' Force SW to be symmetrical
SW1D = Data.GetNMRParameter("SW +/-")
'SW2D = 2* SW1D
'Data.SetNMRParameter "SW 2D", SW2D

' Get dashboard dimension info for apodizations 
LB1D = Data.GetNMRParameter("LB 1D")
LB2D = Data.GetNMRParameter("LB 2D")
GB1D = Data.GetNMRParameter("GB 1D")
GB2D = Data.GetNMRParameter("GB 2D")

' Get user input for apodization
' Apodization type: 1 = exponential
'                   2 = gaussian
'                   4 = sine bell
ApoType1D = 2
ApoType2D = 2
ApoType1D = inputbox("Apodization type - Direct dimension" & vbcrlf & "1=EM, 2=GM, 4=sine bell", version, ApoType1D)
ApoType2D = inputbox("Apodization type - Indirect dimension" & vbcrlf & "1=EM, 2=GM, 4=sine bell", version, ApoType2D)

' Set up sine-bell apodization widths in both dimensions
if ((Pts1D-Pts1DFinal)<0) then
 Apod1D = Pts1D
else
 Apod1D = Pts1DFinal
end if

if ((Pts2D-Pts2DFinal)<0) then
 Apod2D = Pts2D
else
 Apod2D = Pts2DFinal
end if


' Set up for 1D Apod:Dim, param1, param2, param3, param4 
if (ApoType1D = 1) then    ' EM
 Data.SetNDApodisation 1,    LB1D, Apod1D,    1,    0 
elseif (ApoType1D=2) then ' GM
 Data.SetNDApodisation 1,    GB1D, Apod1D,    1,    0 
else                       ' sine bell
 Data.SetNDApodisation 1,    0,    Apod1D,    1,    0 
end if

' Process the first dimension
' Set up for nD FT:  Dim, BC, #ZF,  FT type, rev, ph corr, apod 
Data.SetNDParameters 1, False, zf1d,   1,    False,   2,  ApoType1D
Data.SetNDParameters 2, False, 0,      0,    False,   0,  0
Data.ndft
'msgbox "1dft done"

' Hypercomplex transpose
Data.NDTranspose 2, 1, 3, 4
'msgbox "transpose done"

' Set up for 2D Apod:Dim, param1, param2, param3, param4 
if (ApoType1D = 1) then    ' EM
 Data.SetNDApodisation 1,    LB2D, Apod2D,    1,    0 
elseif (ApoType1D=2) then ' GM
 Data.SetNDApodisation 1,    GB2D, Apod2D,    1,    0 
else                       ' sine bell
 Data.SetNDApodisation 1,    0,    Apod2D,    1,    0 
end if

' Process the second dimension
' Set up for nD FT:  Dim, BC, #ZF,  FT type, rev, ph corr, apod 
Data.SetNDParameters 1, False, zf2d,   1,    False,   0,  ApoType2D
Data.SetNDParameters 2, False, 0,      0,    False,   0,  0
Data.ndft
'msgbox "2nd 1dft done"

' Rearrange and discard the duplicate (mirror image) data set
Data.ResetDimensionInfo Pts2DFinal, Pts1DFinal, 1, 1
Data.ReadFirstHalf
' Reverse spectrum in indirect dimension (depends on RuSH cycle ?)
'Data.ReverseSpectrumColumns

' Complex transpose back
Data.Transpose
'msgbox "transpose done"


' Display the data (note syntax differs from manual!)
' This uses magn data, gray level display, square
' since it is faster than the contour plot for a first look
'                data type, disp type, aspect,
'Data.OpenTwoDView 2,       1,       0
'Data.OpenTwoDView 2,       1,       2
' This uses real data, contour display, aspect=by data
Data.OpenTwoDView 0,       0,       2

' Restore the NDFT button to a useful state for 1D use
Data.SetNDParameters 1, False,    0,   1,    False,   2,  0
Data.SetNDParameters 2, False,    0,   0,    False,   0,  0

MsgBox "2D Processing Done!", vbOKonly, version

end if